@@ -2,11 +2,12 @@
     absolute_paths_not_starting_with_crate,
     ambiguous_associated_items,
     anonymous_parameters,
+    array_into_iter,
+    bindings_with_variant_name,
     const_err,
     dead_code,
     deprecated,
     deprecated_in_future,
-    duplicate_macro_exports,
     ellipsis_inclusive_range_patterns,
     exceeding_bitshifts,
     explicit_outlives_requirements,
@@ -14,20 +15,20 @@
     ill_formed_attribute_input,
     illegal_floating_point_literal_pattern,
     improper_ctypes,
+    incomplete_features,
     indirect_structural_match,
     invalid_type_param_default,
+    invalid_value,
     irrefutable_let_patterns,
     keyword_idents,
     late_bound_lifetime_arguments,
-    legacy_constructor_visibility,
-    legacy_directory_ownership,
     macro_expanded_macro_exports_accessed_by_absolute_paths,
+    meta_variable_misuse,
     missing_copy_implementations,
     missing_docs,
     missing_fragment_specifier,
     mutable_borrow_reservation_conflict,
     mutable_transmutes,
-    nested_impl_trait,
     no_mangle_const_items,
     no_mangle_generic_items,
     non_ascii_idents,
@@ -37,24 +38,24 @@
     non_upper_case_globals,
     order_dependent_trait_objects,
     overflowing_literals,
-    parenthesized_params_in_types_and_modules,
+    overlapping_patterns,
     path_statements,
     patterns_in_fns_without_body,
-    plugin_as_library,
     private_doc_tests,
     private_in_public,
     proc_macro_derive_resolution_fallback,
     pub_use_of_private_extern_crate,
-    safe_extern_statics,
+    redundant_semicolon,
     safe_packed_borrows,
+    soft_unstable,
     stable_features,
     trivial_bounds,
     trivial_casts,
     trivial_numeric_casts,
     type_alias_bounds,
     tyvar_behind_raw_pointer,
+    uncommon_codepoints,
     unconditional_recursion,
-    unions_with_drop_fields,
     unknown_crate_types,
     unnameable_test_items,
     unreachable_code,
@@ -131,3 +132,14 @@ pub mod types;
 
 #[cfg(test)]
 mod test;
+
+#[cfg(test)]
+#[path = "./lib_test.rs"]
+mod lib_test;
+
+static VERSION: &str = env!("CARGO_PKG_VERSION");
+
+/// Returns the library version.
+pub fn version() -> String {
+    VERSION.to_string()
+}
